@@ -6,7 +6,7 @@ use warnings;
 
 use Exporter 'import';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our @EXPORT_OK = qw(all_reachable);
 
@@ -48,7 +48,7 @@ Algorithm::Graphs::Reachable::Tiny - Compute rechable nodes in a graph.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 
 =head1 SYNOPSIS
@@ -99,8 +99,9 @@ forced to use C<undef> as hash value.
 I<C<GRAPH>> must be a reference to a hash. It represents the graph as described above.
 I<C<NODES>> must be a reference to a hash or an array.
 
-The function determines all nodes in I<C<GRAPH>> that are reachable from one
-of the nodes in I<C<NODES>>. It returns a reference to a hash representing this set.
+The function determines the set of all nodes in I<C<GRAPH>> that are reachable
+from one of the nodes in I<C<NODES>>. It returns a reference to a hash
+that represents this set.
 
 =over
 
